@@ -4,9 +4,10 @@ import re
 import numpy as np
 import numpy.typing as npt
 
-from code_loader.contract.enums import DataStateType, DataStateEnum, LeapDataType, ConfusionMatrixValue, MetricDirection
+from code_loader.contract.enums import DataStateType, DataStateEnum, LeapDataType, ConfusionMatrixValue, \
+    MetricDirection, DatasetMetadataType
 from code_loader.contract.visualizer_classes import LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
-    LeapTextMask, LeapImageMask, LeapImageWithBBox, LeapImageWithHeatmap
+    LeapTextMask, LeapImageMask, LeapImageWithBBox, LeapImageWithHeatmap, LeapVideo
 
 custom_latent_space_attribute = "custom_latent_space"
 
@@ -93,6 +94,7 @@ class UnlabeledDataPreprocessHandler:
 
 VisualizerCallableInterface = Union[
     Callable[..., LeapImage],
+    Callable[..., LeapVideo],
     Callable[..., LeapText],
     Callable[..., LeapGraph],
     Callable[..., LeapHorizontalBar],
@@ -141,7 +143,7 @@ class MetricHandlerData:
     name: str
     arg_names: List[str]
     direction: Union[None, MetricDirection, Dict[str, MetricDirection]] = MetricDirection.Downward
-    compute_insights: Union[bool, Dict[str, bool]] = True
+    compute_insights: Optional[Union[bool, Dict[str, bool]]] = None
 
 
 @dataclass
@@ -196,6 +198,7 @@ class GroundTruthHandler(DatasetBaseHandler):
 class MetadataHandler:
     name: str
     function: MetadataSectionCallableInterface
+    metadata_type: Optional[Union[DatasetMetadataType, Dict[str, DatasetMetadataType]]] = None
 
 
 @dataclass
@@ -232,6 +235,7 @@ class DatasetIntegrationSetup:
 class DatasetSample:
     inputs: Dict[str, npt.NDArray[np.float32]]
     gt: Optional[Dict[str, npt.NDArray[np.float32]]]
-    metadata: Dict[str, Union[str, int, bool, float]]
+    metadata: Dict[str, Union[Optional[str], int, bool, Optional[float]]]
+    metadata_is_none: Dict[str, bool]
     index: Union[int, str]
     state: DataStateEnum
